@@ -6,11 +6,11 @@ import subprocess
 import sys
 import threading
 import unicodedata
+from copy import deepcopy
 from shlex import split
 from site import getsitepackages
 from sys import platform
 from time import sleep
-from copy import deepcopy
 
 import jsonpickle
 import numpy
@@ -23,10 +23,12 @@ from pyplan_core.classes.evaluators.Evaluator import Evaluator
 from pyplan_core.classes.Intellisense import Intellisense
 from pyplan_core.classes.IOModule import IOModule
 from pyplan_core.classes.PyplanFunctions import PyplanFunctions, Selector
-from pyplan_core.classes.wizards import (CalculatedField, DataframeGroupby,
-                                         DataframeIndex, SelectColumns,
-                                         SelectRows, sourcecsv, DataarrayFromPandas, InputTable)
-from .DefaultNodeFormats import default_formats                                         
+from pyplan_core.classes.wizards import (CalculatedField, DataarrayFromPandas,
+                                         DataframeGroupby, DataframeIndex,
+                                         InputTable, SelectColumns, SelectRows,
+                                         sourcecsv, CreateIndex, IndexFromPandas, DataArrayFilter)
+
+from .DefaultNodeFormats import default_formats
 
 
 class Model(object):
@@ -120,7 +122,6 @@ class Model(object):
         self._scenarioDic = dict()
         self._wizard = None
 
-
     def connectToWS(self, company_code, session_key):
         # Connect to WS
         self.company_code = company_code
@@ -216,7 +217,7 @@ class Model(object):
             options -= 1
             found = False
             for node in self.findNodes('moduleId', moduleId):
-                if node.nodeClass!="text":
+                if node.nodeClass != "text":
                     l2x = int(node.x)
                     l2y = int(node.y)
                     r2x = int(node.x) + int(node.w)
@@ -1226,7 +1227,6 @@ class Model(object):
                 node.fromObj(obj)
                 node = None
 
-        self.createDefaultNodes()
         [self.nodeDic[nod].generateIO() for nod in self.nodeDic]
 
         opened = None
@@ -1320,25 +1320,31 @@ class Model(object):
         node.definition = "result = ''"
 
     def createSymlinks(self, fileName):
-        if os.getenv('PYPLAN_IDE', '0') != '1' and not os.getenv('ENGINE_MODE', '') in ['fixed', 'local']:
-            # Add user or public path to system paths
-            path_sep = os.path.sep
-            path_arr = fileName[:fileName.rfind(path_sep)].split(path_sep)
+        if os.getenv('PYPLAN_IDE', '0') == '1' or os.getenv('ENGINE_MODE', '') in ['fixed', 'local']:
+            return
 
-            dest_path = path_sep.join(path_arr[:6 if path_arr[4] == 'Workgroups' else 5])
+        # Add user or public path to system paths
+        path_sep = os.path.sep
+        path_arr = fileName[:fileName.rfind(path_sep)].split(path_sep)
 
-            # Get python folder path
-            python_folder = f'python{sys.version[:3]}'
-            try:
-                folder_list = os.listdir(os.path.join(dest_path, '.venv', 'lib'))
-                python_folder = folder_list[len(folder_list)-1]
-            except Exception as ex:
-                pass
+        dest_path = path_sep.join(
+            path_arr[:6 if path_arr[4] == 'Workgroups' else 5])
 
-            # Add user/public library to system paths
-            user_lib_path = os.path.join(dest_path, '.venv', 'lib', python_folder, 'site-packages')
-            venv_path = os.path.join('/venv', 'lib', 'python3.7', 'site-packages')
+        # Get python folder path
+        python_folder = f'python{sys.version[:3]}'
+        try:
+            folder_list = os.listdir(os.path.join(dest_path, '.venv', 'lib'))
+            python_folder = folder_list[len(folder_list)-1]
+        except Exception as ex:
+            pass
 
+        # Add user/public library to system paths
+        user_lib_path = os.path.join(
+            dest_path, '.venv', 'lib', python_folder, 'site-packages')
+        venv_path = os.path.join('/venv', 'lib', 'python3.7', 'site-packages')
+
+        # Check Write Access to user_lib_path
+        if os.access(user_lib_path, os.W_OK):
             if not os.path.isdir(user_lib_path):
                 os.makedirs(user_lib_path, exist_ok=True)
 
@@ -1349,18 +1355,6 @@ class Model(object):
             os.system(f'rm -rf {venv_path}')
             os.system(f'ln -s -f {user_lib_path} {venv_path}')
 
-    def createDefaultNodes(self):
-        """ Create default nodes as pyplan library, etc """
-
-        # modulo pyplan library
-        if not self.existNode('pyplan_library'):
-            pyplan_library_node = self.createNode(
-                identifier='pyplan_library', moduleId=self.modelNode.identifier, x=50, y=500, nodeClass='module')
-            pyplan_library_node.title = 'Pyplan library'
-            pyplan_library_node.color = '#9fc5e8'
-            pyplan_library_node.nodeInfo['showInputs'] = 0
-            pyplan_library_node.nodeInfo['showOutputs'] = 0
-
     def applyBackwardCompatibility(self):
         # update old selector definition
         if self.existNode("selector"):
@@ -1371,9 +1365,9 @@ class Model(object):
         # check for cubepy in imports node
         if self.existNode("imports"):
             node = self.getNode("imports")
-            if ", cubepy," in node.definition:
-                node.definition = node.definition.replace(
-                    ", cubepy,", ", pyplan_core.cubepy as cubepy,")
+            if "cubepy" in node.definition and not "cubepy" in sys.modules:
+                sys.modules["cubepy"] = cubepy
+
 
     def isLinux(self):
         if platform == 'linux' or platform == 'linux2' or platform == 'darwin':
@@ -1547,7 +1541,13 @@ class Model(object):
             return DataarrayFromPandas.Wizard()
         elif key == 'inputtable':
             return InputTable.Wizard()
-            
+        elif key == 'createindex':
+            return CreateIndex.Wizard()
+        elif key == 'indexfrompandas':
+            return IndexFromPandas.Wizard()
+        elif key == 'dataarrayfilter':
+            return DataArrayFilter.Wizard()
+        
 
     def getSystemResources(self, onlyMemory=False):
         """Return current system resources"""
