@@ -7,7 +7,7 @@ from pyplan_core.classes.evaluators.BaseEvaluator import BaseEvaluator
 from pyplan_core.classes.common.filterChoices import filterChoices
 from pyplan_core.classes.common.indexValuesReq import IndexValuesReq
 from pyplan_core.cubepy.cube import kindToString
-from pyplan_core import cubepy 
+from pyplan_core import cubepy
 
 
 class PandasEvaluator(BaseEvaluator):
@@ -315,8 +315,11 @@ class PandasEvaluator(BaseEvaluator):
                     "name": field
                 }
                 if field in nodeDic:
-                    if nodeDic[field].numberFormat:
-                        itemDim["numberFormat"] = nodeDic[field].numberFormat
+                    node = nodeDic[field]
+                    if node.numberFormat:
+                        itemDim["numberFormat"] = node.numberFormat
+                    if node.title:
+                        itemDim["name"] = node.title
                 else:
                     if "datetime" in _result.index.get_level_values(field).dtype.name:
                         itemDim["numberFormat"] = "2,DD,0,,0,0,4,0,$,5,FULL,0"
@@ -505,7 +508,7 @@ class PandasEvaluator(BaseEvaluator):
         """Method executed after calculate node
         """
         if node.nodeClass == "index":
-            if isinstance(result, pd.Index) and result.name is None:
+            if isinstance(result, pd.Index):
                 result.name = node.identifier
 
     def copyAsValues(self, result, nodeDic, nodeId):
